@@ -1,7 +1,7 @@
 """
 This package contains fake data for testing LibreLingo-related packages.
 
-The fake data is returned using the types from `[libreling-types](https://pypi.org/project/librelingo-types/).
+The fake data is returned using the types from [librelingo-types](https://pypi.org/project/librelingo-types/).
 
 ## Usage
 ```python
